@@ -467,9 +467,11 @@ impl Options {
             }
 
             let comments = comments.cloned();
+            let source_map = cm.clone();
             crate::plugin::plugins(
                 Some(plugin_resolver),
                 comments,
+                source_map,
                 experimental,
                 plugin_context,
             )
@@ -494,7 +496,8 @@ impl Options {
 
             swc_plugin_runner::cache::init_plugin_module_cache_once();
             let comments = comments.cloned();
-            crate::plugin::plugins(None, comments, experimental, plugin_context)
+            let source_map = cm.clone();
+            crate::plugin::plugins(None, comments, source_map, experimental, plugin_context)
         };
 
         #[cfg(not(feature = "plugin"))]
@@ -797,7 +800,7 @@ pub struct JsMinifyOptions {
     #[serde(default)]
     pub safari10: bool,
 
-    #[serde(default)]
+    #[serde(default = "true_by_default")]
     pub toplevel: bool,
 
     #[serde(default)]
@@ -1708,7 +1711,6 @@ impl Merge for swc_ecma_parser::EsConfig {
         self.decorators_before_export |= from.decorators_before_export;
         self.export_default_from |= from.export_default_from;
         self.import_assertions |= from.import_assertions;
-        self.static_blocks |= from.static_blocks;
         self.private_in_object |= from.private_in_object;
     }
 }
